@@ -1,7 +1,7 @@
 package App::picadata;
 use v5.14.1;
 
-our $VERSION = '1.31';
+our $VERSION = '1.32';
 
 use Getopt::Long qw(GetOptionsFromArray :config bundling);
 use Pod::Usage;
@@ -33,8 +33,12 @@ my %TYPES = (
     ndjson => 'JSON',
 );
 
-my %COLORS
-    = (tag => 'blue', occurrence => 'blue', code => 'red', value => 'green');
+my %COLORS = (
+    tag        => 'magenta',
+    occurrence => 'magenta',
+    code       => 'red',
+    value      => 'green'
+);
 
 sub new {
     my ($class, @argv) = @_;
